@@ -1,17 +1,17 @@
 from __future__ import absolute_import, print_function
 
-import sys
+import os, sys
 from os.path import dirname
 
-__version__ = '0.7.6'
+__version__ = '0.7.10'
 
 def detect_mode():
     try: import google.appengine
     except ImportError: pass
     else:
-        try: import dev_appserver
-        except ImportError: return 'GAE-SERVER'
-        return 'GAE-LOCAL'
+        if os.environ.get('SERVER_SOFTWARE', '').startswith('Development'):
+            return 'GAE-LOCAL'
+        return 'GAE-SERVER'
 
     try: from mod_wsgi import version
     except: pass
